#[repr(u8)]pub enum Smod {
DISABLE = 0,
RECEIVE = 1,
TRANSMIT = 2,
_RESERVED_3 = 3,
MATCHSTORE = 4,
MATCHCONT = 5,
STATE = 6,
LOGIC = 7,
}Variants
DISABLE = 0
Disabled.
RECEIVE = 1
Receive mode. Captures the current Shifter content into the SHIFTBUF on expiration of the Timer.
TRANSMIT = 2
Transmit mode. Load SHIFTBUF contents into the Shifter on expiration of the Timer.
_RESERVED_3 = 3
MATCHSTORE = 4
Match Store mode. Shifter data is compared to SHIFTBUF content on expiration of the Timer.
MATCHCONT = 5
Match Continuous mode. Shifter data is continuously compared to SHIFTBUF contents.
STATE = 6
State mode. SHIFTBUF contents are used for storing programmable state attributes.
LOGIC = 7
Logic mode. SHIFTBUF contents are used for implementing programmable logic look up table.
Implementations