#[repr(u8)]pub enum Timrst {
NEVER = 0,
_RESERVED_1 = 1,
PIN_EQ_TMR_OUT = 2,
TRIG_EQ_TMR_OUT = 3,
PIN_RISE_EDGE = 4,
_RESERVED_5 = 5,
TRIG_RISE_EDGE = 6,
TRIG_EDGE = 7,
}Variants
NEVER = 0
Timer never reset.
_RESERVED_1 = 1
PIN_EQ_TMR_OUT = 2
Timer reset on Timer Pin equal to Timer Output.
TRIG_EQ_TMR_OUT = 3
Timer reset on Timer Trigger equal to Timer Output.
PIN_RISE_EDGE = 4
Timer reset on Timer Pin rising edge.
_RESERVED_5 = 5
TRIG_RISE_EDGE = 6
Timer reset on Trigger rising edge.
TRIG_EDGE = 7
Timer reset on Trigger rising or falling edge.
Implementations